@@ -23,16 +23,15 @@
 typedef struct s_dichl { struct s_dichlitem *head; } cdichl;
 
 struct s_dichlitem
-{
-	u64			key1;
-	u64			key2;
-	char			*str;
-	struct s_dichlitem	*next;
+{   u64                 key1;
+    u64                 key2;
+    char                *str;
+    struct s_dichlitem  *next;
 };
 
-cdichl	*dichl_alloc();
-int	dichl_destroy(cdichl *d);
-int	dichl_add(cdichl *d, u64 key1, u64 key2, char *str);
-int	dichl_get(cdichl *d, u64 key1, u64 key2, char *buf, int bufsize);
+cdichl *dichl_alloc();
+int    dichl_destroy(cdichl *d);
+int    dichl_add(cdichl *d, u64 key1, u64 key2, char *str);
+int    dichl_get(cdichl *d, u64 key1, u64 key2, char *buf, int bufsize);
 
 #endif // __DICHL_H__
